==> platform-4.9.1-sources.jar: com/gtis/plat/vo/StuffConfigVo.java <==
package com.gtis.plat.vo;
/**
 * @文件名 PfStuffConfigVo.java
 * @注释
 * @作者 deery
 * @创建日期 2013年08月14日
 * @创建时间 09:46:00
 * @版本号 V 1.0
 */
public class StuffConfigVo {
	private String stuffId;//
	private String proId;// 项目ID
	private Integer stuffXh;// 资料序号
	private String stuffName;// 材料名称
	private String meterial;//
	private Integer stuffCount;// 份数
	private String remark;// 备注
	private String workflowDefinitionId;// 工作流定义ID
	private Integer ysnum;// 已收份数
	private Integer dbnum;// 待补份数
	public String getStuffId() {
		return stuffId;
	}
	public void setStuffId(String stuffId) {
		this.stuffId = stuffId;
	}
	public String getProId() {
		return proId;
	}
	public void setProId(String proId) {
		this.proId = proId;
	}
	public Integer getStuffXh() {
		return stuffXh;
	}
	public void setStuffXh(Integer stuffXh) {
		this.stuffXh = stuffXh;
	}
	public String getStuffName() {
		return stuffName;
	}
	public void setStuffName(String stuffName) {
		this.stuffName = stuffName;
	}
	public String getMeterial() {
		return meterial;
	}
	public void setMeterial(String meterial) {
		this.meterial = meterial;
	}
	public Integer getStuffCount() {
		return stuffCount;
	}
	public void setStuffCount(Integer stuffCount) {
		this.stuffCount = stuffCount;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getWorkflowDefinitionId() {
		return workflowDefinitionId;
	}
	public void setWorkflowDefinitionId(String workflowDefinitionId) {
		this.workflowDefinitionId = workflowDefinitionId;
	}
	public Integer getYsnum() {
		return ysnum;
	}
	public void setYsnum(Integer ysnum) {
		this.ysnum = ysnum;
	}
	public Integer getDbnum() {
		return dbnum;
	}
	public void setDbnum(Integer dbnum) {
		this.dbnum = dbnum;
	}
}

==> platform-4.9.13-sources.jar: com/gtis/plat/vo/StuffConfigVo.java <==
package com.gtis.plat.vo;

import java.util.ArrayList;
import java.util.List;

/**
 * @文件名 PfStuffConfigVo.java
 * @注释
 * @作者 deery
 * @创建日期 2013年08月14日
 * @创建时间 09:46:00
 * @版本号 V 1.0
 */
public class StuffConfigVo {
	private String stuffId;//
	private String proId;// 项目ID
	private Integer stuffXh;// 资料序号
	private String stuffName;// 材料名称
	private String meterial;//
	private Integer stuffCount;// 份数
	private String remark;// 备注
	private String workflowDefinitionId;// 工作流定义ID
	private Integer ysnum;// 已收份数
	private Integer dbnum;// 待补份数

	List<StuffConfigVo> children = new ArrayList<StuffConfigVo>();
	public String getStuffId() {
		return stuffId;
	}
	public void setStuffId(String stuffId) {
		this.stuffId = stuffId;
	}
	public String getProId() {
		return proId;
	}
	public void setProId(String proId) {
		this.proId = proId;
	}
	public Integer getStuffXh() {
		return stuffXh;
	}
	public void setStuffXh(Integer stuffXh) {
		this.stuffXh = stuffXh;
	}
	public String getStuffName() {
		return stuffName;
	}
	public void setStuffName(String stuffName) {
		this.stuffName = stuffName;
	}
	public String getMeterial() {
		return meterial;
	}
	public void setMeterial(String meterial) {
		this.meterial = meterial;
	}
	public Integer getStuffCount() {
		return stuffCount;
	}
	public void setStuffCount(Integer stuffCount) {
		this.stuffCount = stuffCount;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getWorkflowDefinitionId() {
		return workflowDefinitionId;
	}
	public void setWorkflowDefinitionId(String workflowDefinitionId) {
		this.workflowDefinitionId = workflowDefinitionId;
	}
	public Integer getYsnum() {
		return ysnum;
	}
	public void setYsnum(Integer ysnum) {
		this.ysnum = ysnum;
	}
	public Integer getDbnum() {
		return dbnum;
	}
	public void setDbnum(Integer dbnum) {
		this.dbnum = dbnum;
	}

	public List<StuffConfigVo> getChildren() {
		return children;
	}

	public void setChildren(List<StuffConfigVo> children) {
		this.children = children;
	}
	public void addChild(StuffConfigVo ztree) {
		children.add(ztree);
	}

}
